pub struct Invoice {Show 15 fields
pub invoice_type: InvoiceType,
pub id: String,
pub reference_number: Option<String>,
pub date: String,
pub remit_to_party: Box<PartyIdentification>,
pub ship_to_party: Option<Box<PartyIdentification>>,
pub ship_from_party: Option<Box<PartyIdentification>>,
pub bill_to_party: Option<Box<PartyIdentification>>,
pub payment_terms: Option<Box<PaymentTerms>>,
pub invoice_total: Box<Money>,
pub tax_details: Option<Vec<TaxDetails>>,
pub additional_details: Option<Vec<AdditionalDetails>>,
pub charge_details: Option<Vec<ChargeDetails>>,
pub allowance_details: Option<Vec<AllowanceDetails>>,
pub items: Option<Vec<InvoiceItem>>,
}Fields
invoice_type: InvoiceTypeIdentifies the type of invoice.
id: StringUnique number relating to the charges defined in this document. This will be invoice number if the document type is Invoice or CreditNote number if the document type is Credit Note. Failure to provide this reference will result in a rejection.
reference_number: Option<String>An additional unique reference number used for regulatory or other purposes.
date: StringDefines a date and time according to ISO8601.
remit_to_party: Box<PartyIdentification>ship_to_party: Option<Box<PartyIdentification>>ship_from_party: Option<Box<PartyIdentification>>bill_to_party: Option<Box<PartyIdentification>>payment_terms: Option<Box<PaymentTerms>>invoice_total: Box<Money>tax_details: Option<Vec<TaxDetails>>Total tax amount details for all line items.
additional_details: Option<Vec<AdditionalDetails>>Additional details provided by the selling party, for tax related or other purposes.
charge_details: Option<Vec<ChargeDetails>>Total charge amount details for all line items.
allowance_details: Option<Vec<AllowanceDetails>>Total allowance amount details for all line items.
items: Option<Vec<InvoiceItem>>The list of invoice items.
Implementations
sourceimpl Invoice
impl Invoice
pub fn new(
invoice_type: InvoiceType,
id: String,
date: String,
remit_to_party: PartyIdentification,
invoice_total: Money
) -> Invoice